==> electricsql-0.4.0.tar.gz: lib/src/satellite/satellite.dart <==
import 'package:electricsql/src/auth/auth.dart';
import 'package:electricsql/src/client/model/schema.dart';
import 'package:electricsql/src/config/config.dart';
import 'package:electricsql/src/electric/adapter.dart' hide Transaction;
import 'package:electricsql/src/migrators/migrators.dart';
import 'package:electricsql/src/notifiers/notifiers.dart';
import 'package:electricsql/src/satellite/process.dart';
import 'package:electricsql/src/satellite/shapes/types.dart';
import 'package:electricsql/src/sockets/sockets.dart';
import 'package:electricsql/src/util/types.dart';
import 'package:events_emitter/events_emitter.dart';

export 'package:electricsql/src/satellite/process.dart' show ShapeSubscription;

abstract class Registry {
  Map<DbName, Satellite> get satellites;

  Future<Satellite> ensureStarted({
    required DbName dbName,
    required DBSchema dbDescription,
    required DatabaseAdapter adapter,
    required Migrator migrator,
    required Notifier notifier,
    required SocketFactory socketFactory,
    required HydratedConfig config,
  });

  Future<Satellite> ensureAlreadyStarted(DbName dbName);

  Future<void> stop(DbName dbName);

  Future<void> stopAll();
}

class ConnectionWrapper {
  final Future<void> connectionFuture;

  ConnectionWrapper({
    required this.connectionFuture,
  });
}

abstract class Satellite {
  DbName get dbName;
  DatabaseAdapter get adapter;
  Migrator get migrator;
  Notifier get notifier;

  ConnectivityState? connectivityState;

  Future<ConnectionWrapper> start(AuthConfig authConfig);
  Future<void> stop({bool? shutdown});
  Future<ShapeSubscription> subscribe(
    List<ClientShapeDefinition> shapeDefinitions,
  );
  Future<void> unsubscribe(String shapeUuid);
}

abstract class Client {
  Future<void> connect();
  void disconnect();
  void shutdown();
  Future<AuthResponse> authenticate(
    AuthState authState,
  );
  bool isConnected();
  Future<StartReplicationResponse> startReplication(
    LSN? lsn,
    String? schemaVersion,
    List<String>? subscriptionIds,
  );
  Future<StopReplicationResponse> stopReplication();
  void subscribeToRelations(RelationCallback callback);
  void unsubscribeToRelations(EventListener<Relation> eventListener);
  void subscribeToTransactions(TransactionCallback callback);
  void unsubscribeToTransactions(EventListener<TransactionEvent> eventListener);
  void enqueueTransaction(
    DataTransaction transaction,
  );
  LSN getLastSentLsn();
  EventListener<void> subscribeToOutboundStarted(
    OutboundStartedCallback callback,
  );
  void unsubscribeToOutboundStarted(EventListener<LSN> eventListener);
  EventListener<SatelliteException> subscribeToError(ErrorCallback callback);
  void unsubscribeToError(EventListener<SatelliteException> eventListener);

  Future<SubscribeResponse> subscribe(
    String subscriptionId,
    List<ShapeRequest> shapes,
  );
  Future<UnsubscribeResponse> unsubscribe(List<String> subIds);

  SubscriptionEventListeners subscribeToSubscriptionEvents(
    SubscriptionDeliveredCallback successCallback,
    SubscriptionErrorCallback errorCallback,
  );
  void unsubscribeToSubscriptionEvents(SubscriptionEventListeners listeners);
}

class SubscriptionEventListeners {
  final EventListener<SubscriptionData> successEventListener;
  final EventListener<SubscriptionErrorData> errorEventListener;

  SubscriptionEventListeners({
    required this.successEventListener,
    required this.errorEventListener,
  });
}

==> electricsql-0.6.0.tar.gz: lib/src/satellite/satellite.dart <==
import 'package:electricsql/src/auth/auth.dart';
import 'package:electricsql/src/client/model/schema.dart';
import 'package:electricsql/src/config/config.dart';
import 'package:electricsql/src/electric/adapter.dart';
import 'package:electricsql/src/migrators/migrators.dart';
import 'package:electricsql/src/notifiers/notifiers.dart';
import 'package:electricsql/src/satellite/process.dart';
import 'package:electricsql/src/satellite/shapes/types.dart';
import 'package:electricsql/src/sockets/sockets.dart';
import 'package:electricsql/util.dart';
import 'package:fixnum/fixnum.dart';

export 'package:electricsql/src/satellite/process.dart' show ShapeSubscription;

abstract class Registry {
  Map<DbName, Satellite> get satellites;

  Future<Satellite> ensureStarted({
    required DbName dbName,
    required DBSchema dbDescription,
    required DatabaseAdapter adapter,
    required Migrator migrator,
    required Notifier notifier,
    required SocketFactory socketFactory,
    required HydratedConfig config,
  });

  Future<Satellite> ensureAlreadyStarted(DbName dbName);

  Future<void> stop(DbName dbName);

  Future<void> stopAll();
}

abstract class Satellite {
  DbName get dbName;
  DatabaseAdapter get adapter;
  Migrator get migrator;
  Notifier get notifier;

  ConnectivityState? connectivityState;

  Future<void> start(AuthConfig? authConfig);
  Future<void> stop({bool? shutdown});
  void setToken(String token);
  bool hasToken();
  Future<void> connectWithBackoff();
  void disconnect(SatelliteException? error);
  void clientDisconnect();
  Future<void> authenticate(String token);
  Future<ShapeSubscription> subscribe(
    List<Shape> shapeDefinitions,
  );
  Future<void> unsubscribe(String shapeUuid);

  void setReplicationTransform(
    QualifiedTablename tableName,
    ReplicatedRowTransformer<Record> transform,
  );
  void clearReplicationTransform(QualifiedTablename tableName);
}

abstract class Client {
  Future<void> connect();
  void disconnect();
  void shutdown();
  Future<AuthResponse> authenticate(
    AuthState authState,
  );
  bool isConnected();
  ReplicationStatus getOutboundReplicationStatus();
  Future<StartReplicationResponse> startReplication(
    LSN? lsn,
    String? schemaVersion,
    List<String>? subscriptionIds,
    List<Int64> observedTransactionData,
  );
  Future<StopReplicationResponse> stopReplication();
  void Function() subscribeToRelations(RelationCallback callback);
  void Function() subscribeToTransactions(TransactionCallback callback);
  void Function() subscribeToAdditionalData(AdditionalDataCallback callback);
  void enqueueTransaction(
    DataTransaction transaction,
  );
  LSN getLastSentLsn();
  void Function() subscribeToOutboundStarted(
    OutboundStartedCallback callback,
  );
  void Function() subscribeToError(ErrorCallback callback);

  Future<SubscribeResponse> subscribe(
    String subscriptionId,
    List<ShapeRequest> shapes,
  );
  Future<UnsubscribeResponse> unsubscribe(List<String> subIds);

  SubscriptionEventListeners subscribeToSubscriptionEvents(
    SubscriptionDeliveredCallback successCallback,
    SubscriptionErrorCallback errorCallback,
  );
  void unsubscribeToSubscriptionEvents(SubscriptionEventListeners listeners);

  void setReplicationTransform(
    QualifiedTablename tableName,
    ReplicatedRowTransformer<Record> transform,
  );
  void clearReplicationTransform(QualifiedTablename tableName);
}

class SubscriptionEventListeners {
  final void Function() removeListeners;

  SubscriptionEventListeners({
    required this.removeListeners,
  });
}
